@@ -3,11 +3,10 @@ import abc
 import json
 from dataclasses import asdict
 from datetime import timedelta
-from typing import Any, List, Optional, Tuple
+from typing import Any, List, Optional, Tuple, Type
 from urllib.parse import urlencode
 
 from httpx import Headers
-from typing_extensions import Protocol
 
 from blacksmith.domain.model.http import HTTPRequest, HTTPResponse
 from blacksmith.typing import ClientName, HttpMethod, Path
@@ -78,16 +77,28 @@ except ImportError:
     pass
 
 
-class AbstractSerializer(Protocol):
+class AbstractSerializer(abc.ABC):
     @staticmethod
+    @abc.abstractmethod
     def loads(s: str) -> Any:
         """Load a string to an object"""
 
     @staticmethod
+    @abc.abstractmethod
     def dumps(obj: Any) -> str:
         """Get a value from redis"""
 
 
+class JsonSerializer(AbstractSerializer):
+    @staticmethod
+    def loads(s: str) -> Any:
+        return json.loads(s)
+
+    @staticmethod
+    def dumps(obj: Any) -> str:
+        return json.dumps(obj)
+
+
 def int_or_0(val: str) -> int:
     try:
         ival = int(val)
@@ -99,8 +110,8 @@ def int_or_0(val: str) -> int:
 def get_max_age(response: HTTPResponse) -> int:
     max_age = 0
     age = int_or_0(response.headers.get("age", "0"))
-    cache_control = response.headers.get("cache-control", "")
-    cache_control = [c.strip() for c in cache_control.split(",")]
+    s_cache_control = response.headers.get("cache-control", "")
+    cache_control = [c.strip() for c in s_cache_control.split(",")]
     if "public" in cache_control:
         h_max_age: List[str] = [cc for cc in cache_control if cc.startswith("max-age=")]
         if h_max_age:
@@ -178,7 +189,7 @@ class AsyncHTTPCachingMiddleware(AsyncHTTPMiddleware):
         self,
         cache: AsyncAbstractCache,
         policy: AbstractCachingPolicy = CacheControlPolicy(),
-        serializer: AbstractSerializer = json,
+        serializer: Type[AbstractSerializer] = JsonSerializer,
     ) -> None:
         self._cache = cache
         self._policy = policy
