@@ -5,8 +5,8 @@ from blacksmith.typing import HttpMethod, Proxies
 
 
 class AsyncAbstractTransport(abc.ABC):
-    def __init__(self, verify_verificate: bool = True, proxies: Proxies = None):
-        self.verify_verificate = verify_verificate
+    def __init__(self, verify_certificate: bool = True, proxies: Proxies = None):
+        self.verify_certificate = verify_certificate
         self.proxies = proxies
 
     @abc.abstractmethod
