@@ -2,7 +2,7 @@ from typing import List, Type
 
 from blacksmith.domain.exceptions import UnregisteredResourceException
 from blacksmith.domain.model.http import HTTPTimeout
-from blacksmith.domain.model.params import CollectionParser
+from blacksmith.domain.model.params import AbstractCollectionParser, CollectionParser
 from blacksmith.domain.registry import Registry, Resources
 from blacksmith.domain.registry import registry as default_registry
 from blacksmith.middleware._async.base import AsyncHTTPMiddleware
@@ -11,11 +11,7 @@ from blacksmith.service._async.adapters.httpx import AsyncHttpxTransport
 from blacksmith.typing import ClientName, Proxies, ResourceName, Url
 
 from .base import AsyncAbstractTransport
-from .route_proxy import (
-    AsyncRouteProxy,
-    ClientTimeout,
-    build_timeout,
-)
+from .route_proxy import AsyncRouteProxy, ClientTimeout, build_timeout
 
 
 class AsyncClient:
@@ -30,7 +26,7 @@ class AsyncClient:
     resources: Resources
     transport: AsyncAbstractTransport
     timeout: HTTPTimeout
-    collection_parser: Type[CollectionParser]
+    collection_parser: Type[AbstractCollectionParser]
     middlewares: List[AsyncHTTPMiddleware]
 
     def __init__(
@@ -40,7 +36,7 @@ class AsyncClient:
         resources: Resources,
         transport: AsyncAbstractTransport,
         timeout: HTTPTimeout,
-        collection_parser: Type[CollectionParser],
+        collection_parser: Type[AbstractCollectionParser],
         middlewares: List[AsyncHTTPMiddleware],
     ) -> None:
         self.name = name
@@ -49,7 +45,11 @@ class AsyncClient:
         self.transport = transport
         self.timeout = timeout
         self.collection_parser = collection_parser
-        self.middlewares = middlewares
+        self.middlewares = middlewares.copy()
+
+    def add_middleware(self, middleware: AsyncHTTPMiddleware) -> "AsyncClient":
+        self.middlewares.insert(0, middleware)
+        return self
 
     def __getattr__(self, name: ResourceName) -> AsyncRouteProxy:
         """
@@ -92,7 +92,7 @@ class AsyncClientFactory:
     registry: Registry
     transport: AsyncAbstractTransport
     timeout: HTTPTimeout
-    collection_parser: Type[CollectionParser]
+    collection_parser: Type[AbstractCollectionParser]
     middlewares: List[AsyncHTTPMiddleware]
 
     def __init__(
@@ -103,7 +103,7 @@ class AsyncClientFactory:
         timeout: ClientTimeout = HTTPTimeout(),
         proxies: Proxies = None,
         verify_certificate: bool = False,
-        collection_parser: Type[CollectionParser] = CollectionParser,
+        collection_parser: Type[AbstractCollectionParser] = CollectionParser,
     ) -> None:
         self.sd = sd
         self.registry = registry
